@@ -51,7 +51,7 @@ class CreateBranch:
         branch_name = prompt_utils.ask_questions_input(
             "Enter branch name: ",
             re.sub(
-                r'([\s\\.,~\^:\(\)\[\]\<\>"\'?]|[^\x00-\x7F]|[0-9])+',
+                r'([\s\\.,~\^:\(\)\[\]\<\>"\'?\#]|[^\x00-\x7F]|[0-9])+',
                 "-",
                 issue["summary"],
             ).lower(),
