@@ -73,7 +73,7 @@ class QA:
     def _create_instance_table(self):
         instance_table = Table()
         instance_table.add_column("Name", style="purple")
-        instance_table.add_column("Hash", style="green")
+        instance_table.add_column("Hash", style="green", width=32)
         instance_table.add_column("Card", style="white")
         instance_table.add_column("Created by", style="white")
         instance_table.add_column("Updated by", style="white")
