@@ -159,6 +159,11 @@ class Release:
             self._countries,
         )
 
+        if not countries:
+            logger.error("You must select at least one country!")
+            self._rollback()
+            return
+
         current = self._get_current_versions(countries)
         releases = self._get_releases_before(min(rel["version"] for rel in current))
         if not releases:
